@@ -1,8 +1,11 @@
 import os
+from time import sleep
 
 import boto3
 from botocore.exceptions import ClientError
-from time import sleep
+from sagemaker.feature_store.feature_group import FeatureGroup
+from sagemaker.session import Session
+
 
 def define_feature_group(
     name,
@@ -10,7 +13,7 @@ def define_feature_group(
     record_identifier_feature,
     event_time_feature,
     feature_definitions,
-    online_store_config={'EnableOnlineStore': True},
+    online_store_config={"EnableOnlineStore": True},
     offline_store_config={},
     s3_key=None,
     aws_access_key=None,
@@ -132,7 +135,7 @@ def is_feature_group_different(
     event_time_feature,
     feature_definitions,
     online_store_config,
-    offline_store_config,
+    offline_store,
     role_arn,
     description,
 ):
@@ -141,8 +144,38 @@ def is_feature_group_different(
         FeatureGroupName=feature_group_name
     )
 
-    if 'ResolvedOutputS3Uri' in response['OfflineStoreConfig']:
-        del response['OfflineStoreConfig']['ResolvedOutputS3Uri']
+    offline_store_config = offline_store
+
+    if (
+        "S3StorageConfig" in response["OfflineStoreConfig"]
+        and "S3StorageConfig" in offline_store_config
+    ):
+        if (
+            "ResolvedOutputS3Uri" not in offline_store_config
+            or offline_store_config["S3StorageConfig"]["ResolvedOutputS3Uri"]
+            == response["OfflineStoreConfig"]["S3StorageConfig"]["ResolvedOutputS3Uri"]
+        ):
+            offline_store_config["S3StorageConfig"]["ResolvedOutputS3Uri"] = response[
+                "OfflineStoreConfig"
+            ]["S3StorageConfig"]["ResolvedOutputS3Uri"]
+
+    if (
+        "DisableGlueTableCreation" not in offline_store_config
+        or offline_store_config["DisableGlueTableCreation"]
+        == response["OfflineStoreConfig"]["DisableGlueTableCreation"]
+    ):
+        offline_store_config["DisableGlueTableCreation"] = response[
+            "OfflineStoreConfig"
+        ]["DisableGlueTableCreation"]
+
+    if (
+        "DataCatalogConfig" not in offline_store_config
+        or offline_store_config["DataCatalogConfig"]
+        == response["OfflineStoreConfig"]["DataCatalogConfig"]
+    ):
+        offline_store_config["DataCatalogConfig"] = response["OfflineStoreConfig"][
+            "DataCatalogConfig"
+        ]
 
     return (
         response["RoleArn"] != role_arn
@@ -153,3 +186,54 @@ def is_feature_group_different(
         or response["OfflineStoreConfig"] != offline_store_config
         or response["Description"] != description
     )
+
+
+def load_feature_group(
+    name,
+    aws_access_key=None,
+    aws_secret_key=None,
+    region=None,
+    environment_prefix=None,
+):
+    """
+    Loads a feature group object from the feature store by name
+    """
+    environment_prefix_name = environment_prefix
+
+    aws_access_key_id = (
+        os.environ["AWS_ACCESS_KEY"] if aws_access_key is None else aws_access_key
+    )
+    aws_secret_key_id = (
+        os.environ["AWS_SECRET_KEY"] if aws_secret_key is None else aws_secret_key
+    )
+
+    environment_prefix_name = (
+        os.environ["ENVIRONMENT_PREFIX"]
+        if environment_prefix is None
+        else environment_prefix
+    )
+
+    region_name = boto3.Session().region_name if region is None else region
+    boto_session = boto3.Session(
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_access_key_id,
+        region_name=region_name,
+    )
+
+    sagemaker_client = boto_session.client(
+        service_name="sagemaker", region_name=region_name
+    )
+
+    featurestore_runtime = boto_session.client(
+        service_name="sagemaker-featurestore-runtime", region_name=region_name
+    )
+
+    feature_store_session = Session(
+        boto_session=boto_session,
+        sagemaker_client=sagemaker_client,
+        sagemaker_featurestore_runtime_client=featurestore_runtime,
+    )
+
+    return FeatureGroup(
+        name=f"{environment_prefix_name}{name}", sagemaker_session=feature_store_session
+    )
